@@ -12,14 +12,7 @@ from __future__ import print_function
 
 import os
 
-from . import get_keras_submodule
-
-backend = get_keras_submodule('backend')
-engine = get_keras_submodule('engine')
-layers = get_keras_submodule('layers')
-models = get_keras_submodule('models')
-keras_utils = get_keras_submodule('utils')
-
+from . import get_submodules_from_kwargs
 from . import imagenet_utils
 from .imagenet_utils import decode_predictions
 from .imagenet_utils import _obtain_input_shape
@@ -39,7 +32,8 @@ def VGG19(include_top=True,
           input_tensor=None,
           input_shape=None,
           pooling=None,
-          classes=1000):
+          classes=1000,
+          **kwargs):
     """Instantiates the VGG19 architecture.
 
     Optionally loads weights pre-trained on ImageNet.
@@ -85,6 +79,8 @@ def VGG19(include_top=True,
         ValueError: in case of invalid argument for `weights`,
             or invalid input shape.
     """
+    backend, layers, models, keras_utils = get_submodules_from_kwargs(kwargs)
+
     if not (weights in {'imagenet', None} or os.path.exists(weights)):
         raise ValueError('The `weights` argument should be either '
                          '`None` (random initialization), `imagenet` '
@@ -97,7 +93,7 @@ def VGG19(include_top=True,
     # Determine proper input shape
     input_shape = _obtain_input_shape(input_shape,
                                       default_size=224,
-                                      min_size=48,
+                                      min_size=32,
                                       data_format=backend.image_data_format(),
                                       require_flatten=include_top,
                                       weights=weights)
@@ -203,11 +199,7 @@ def VGG19(include_top=True,
     # Ensure that the model takes into account
     # any potential predecessors of `input_tensor`.
     if input_tensor is not None:
-        if hasattr(keras_utils, 'get_source_inputs'):
-            get_source_inputs = keras_utils.get_source_inputs
-        else:
-            get_source_inputs = engine.get_source_inputs
-        inputs = get_source_inputs(input_tensor)
+        inputs = keras_utils.get_source_inputs(input_tensor)
     else:
         inputs = img_input
     # Create model.
